@@ -1,8 +1,8 @@
 
-from ncplot import ncplot
 
 
 def plot(self, vars=None):
+    from ncplot import view
 
     """
     Autoplotting method.
@@ -19,5 +19,5 @@ def plot(self, vars=None):
     if type(self.current) is list:
         raise TypeError("You cannot view multiple files!")
 
-    return ncplot(self.current, vars = vars)
+    return view(self.current, vars = vars)
 
